Learn R Programming

dfpk (version 1.0)

dfpk-package: A Bayesian Dose-Finding Design using Pharmacokinetics(PK) for Phase I Clinical Trials.

Description

Includes methods involving PK measures in the dose allocation process during a Phase I clinical trials. These methods enter PK in the dose finding designs in different ways, including covariates models, dependent variable or hierarchical models. This package provides functions to generate scenarios, and to run simulations which their objective is to determine the maximum tolerated dose (MTD) and to investigate PK of a drug or a combination of drugs.

Arguments

Details

The two main functions of the dfpk package are scenarios and sim which the first one creates the scenarios for the PK data and the second one simulates the data in order to find the next maximum tolerated dose (MTD) of the drug. Subsequently, six dose-finding methods can be applied: dtox, pktox, pkcrm, pkcov, pkpop, and pklogit which each one creates a Bayesian model and fits it using Stan.

Because dfpk is based on Stan, a C++ compiler is required. The program Rtools (available on https://cran.r-project.org/bin/windows/Rtools/) comes with a C++ compiler for Windows. On Mac, you should use Xcode. For further instructions on how to get the compilers running, see the prerequisites section on https://github.com/stan-dev/rstan/wiki/RStan-Getting-Started.

References

Ursino, M., et al, (2016) Dose-finding methods using pharmacokinetics in small populations (under review).