Learn R Programming

dfpk (version 1.0)

pktox: Dose finding method PKTOX

Description

The PKTOX model was be introduced to test the behaviour of one possible way to estimating probabilities of toxicity. This way consists of estimating probabilities of toxicity of doses passing through the AUC or another PK measure of exposure. This models is essentially the PKLOGIT model with the difference that uses $\Phi$ function instead of logit in the posterior probability of toxicity.

Usage

pktox(y, auc, doses, lev, theta, p_0, L, betapriors, D_AUC, options)

Arguments

y
A vector of patient outcomes; TRUE indicates a toxicity, FALSE otherwise.
auc
The AUC numbers of each patient.
doses
The doses levels of the drug.
lev
A vector of dose levels assigned to patients.
theta
The toxicity (probability) target.
p_0
Skeleton of CRM.
L
A threshold set before starting the trial.
betapriors
A vector of the regression parameters in pktox model; the default is NULL for this model.
D_AUC
A vector specifying the difference between the AUCs and AUC_pop; defaults to NULL.
options
A list of three integers specifying the stan model's number of chains, how many iterations for each chain and the number of warmup iterations. defaults to options <- list(nchains = 4, niter = 4000, nadapt = 0.8)

References

Ursino, M., et al, (2016) Dose-finding methods using pharmacokinetics in small populations (under review).

Whitehead, J., Zhou, Y., Hampson, L., Ledent, E., and Pereira, A. (2007) A bayesian approach for dose-escalation in a phase i clincial trial incorporating pharmacodynamic endpoints. Journal of Biopharmaceutical Statistics, 17 (6), 1117-1129.

See Also

pklogit, scenarios, sim

Examples

Run this code
p_0 = NULL                  
L = NULL 
d <- c(12.59972,34.65492,44.69007,60.80685,83.68946,100.37111)
theta <- 0.2     
options <- list(nchains = 2,
        niter = 4000,
        nadapt = 0.8)  
AUCs <-  c(0.43, 1.4, 5.98, 7.98, 11.90, 3.45)
x <- c(1,2,3,4,5,6)              
y <- c(FALSE,FALSE,FALSE,FALSE,TRUE,FALSE)
D_AUC <- c(0, 1.3, -0.34, -2.7,0.39, -2.45)

### Betapriors ###
betapriors = NULL

pktox(y, AUCs, d, x, theta, p_0, L, betapriors, D_AUC,options)

Run the code above in your browser using DataLab