scenarios and sim which the first one creates the scenarios for the PK data and the second one simulates the data in order to find the next maximum tolerated dose (MTD) of the drug.
Subsequently, six dose-finding methods can be applied: dtox, pktox, pkcrm, pkcov, pkpop, and pklogit which each one creates a Bayesian model and fits it using Stan. Because dfpk is based on Stan, a C++ compiler is required. The program Rtools (available on https://cran.r-project.org/bin/windows/Rtools/) comes with a C++ compiler for Windows. On Mac, you should use Xcode. For further instructions on how to get the compilers running, see the prerequisites section on https://github.com/stan-dev/rstan/wiki/RStan-Getting-Started.