Rdocumentation
powered by
Learn R Programming
dfpk (version 1.0)
plotConc,scen-method: The graphical representation of the drug's concentration in the plasma at time t after the drug administration.
Description
The graphical representation of the drug's concentration in the plasma at time t after the drug administration.
Usage
"plotConc"(x, ...)
Arguments
x
A "scen" object.
...
Other parameters to be passed through to plotting functions. They are ignored in this function.