Rdocumentation
powered by
Learn R Programming
dfpk (version 1.0)
plotDose,dosefinding-method: The graphical representation of dose escalation for each patient in the trial.
Description
The graphical representation of dose escalation for each patient in the trial.
Usage
"plotDose"(x, ...)
Arguments
x
A "dosefinding" object.
...
Other parameters to be passed through to plotting functions. They are ignored in this function.